##  Creating an Architecture Decision
By default, members and admins can create architecture decisions. However, admins can grant this permission to other roles. For details, see [Permissions](https://help.sap.com/docs/leanix/ea/architecture-decisions?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758b7ff7a441014bb6ac52c04964f3b__permissions).
You can create architecture decisions using custom templates that provide a structured format, simplifying the creation process. Users with appropriate permissions can create templates for the workspace. For more details, see [Architecture Decision Templates](https://help.sap.com/docs/leanix/ea/architecture-decision-templates?locale=en-US&state=PRODUCTION&version=CLOUD "Templates provide a predefined structure for architecture decisions, enhancing consistency and streamlining the creation process. Users with appropriate permissions can create custom templates that align with their organization’s decision types.").
To create an architecture decision, follow these steps:
  1. On the navigation bar, click More > Architecture Decisions.
  2. On the Decisions page, click the arrow next to New Decision, then select a template. A page for creating an architecture decision appears, structured based on the selected template.
  3. Populate the decision with relevant information.
**Tip**
The text editor in architecture decisions supports Markdown syntax. To structure information in a decision, use headings, paragraphs, and lists. Apply the necessary formatting to the text.
Use tables to capture structured information, such as comparisons, timelines, prioritization matrices, dependency tracking, risk assessments, status reporting on decision details, or rationale overviews.
  4. Set the decision status:
     * Draft: Select this status to continue editing the decision later.
     * Proposed: Select this status to finish editing the decision and submit the proposal.
  5. Enter a name for the decision in the upper-left corner, then save the changes.
